@@ -3,6 +3,7 @@
 #include <string.h>
 #include <signal.h>
 #include <unistd.h>
+#include <locale.h>
 
 #include "vt.h"
 #include "misc.h"
@@ -39,17 +40,26 @@ usage(FILE *fp, int exitval)
 	    "    -vbi <vbidev>\t\t/dev/vbi0\n"
 	    "    -finetune <-4..4|auto>\t0\n"
 	    //"    -oldbttv\t\t\t(for bttv <0.5.20)\n"
-	    "    -charset latin-1/2\t\tlatin-1\n"
+	    "    -charset latin-1/2/koi8-r/iso8859-7\tlatin-1\n"
 	    "    -timeout <secs>\t\tnone\n"
 	    "    -name <filename>\t\tttext-%%s.%%e\n"
 	    "    -format <fmt[,options]>\tascii\n"
 	    "    -format help\n"
+	    "    -progname name\n"
+	    "    -pid pid\n"
 	    "\n"
 	    "  ppp[.ss] stands for a page number and an\n"
 	    "  optional subpage number (ie 123.4).  If\n"
 	    "  the subpage number is omitted the first\n"
 	    "  transmitted subpage is captured.\n"
 	    "\n"
+	    "\n"
+	    "  To use the DVB interface, use\n"
+	    "  -vbi /dev/dvb/adapter0/demux0\n"
+	    "\n"
+	    "  The -progname or -pid option specify\n"
+	    "  the program or teletext PID if using\n"
+	    "  the DVB interface.\n"
 	);
     exit(exitval);
 }
@@ -130,6 +140,8 @@ option(int argc, char **argv, int *ind, char **arg)
 	{ "-format", "-fmt", 1 },
 	{ "-name", "-o", 1 },
 	{ "-timeout", "-t", 1 },
+	{ "-progname", "-pn", 1 },
+	{ "-pid", "--pid", 1 },
     };
     int i;
 
@@ -192,7 +204,7 @@ event(struct dl_head *reqs, struct vt_event *ev)
 int
 main(int argc, char **argv)
 {
-    char *vbi_name = "/dev/vbi0";
+    char *vbi_name = NULL;
     int fine_tune = 1; // auto = 999;
     int newbttv = -1;
     int timeout = 0;
@@ -204,6 +216,8 @@ main(int argc, char **argv)
     struct vbi *vbi;
     struct req *req;
     struct dl_head reqs[2];	// simple linear lists of requests & captures
+    char *progname = NULL;
+    int txtpid = -1;
 
     setprgname(argv[0]);
 
@@ -244,11 +258,15 @@ main(int argc, char **argv)
 		break;
             case 9:    // charset
 		if (streq(arg, "latin-1") || streq(arg, "1"))
-		    latin1 = 1;
+		    latin1 = LATIN1;
 		else if (streq(arg, "latin-2") || streq(arg, "2"))
-		    latin1 = 0;
+		    latin1 = LATIN2;
+		else if (streq(arg, "koi8-r") || streq(arg, "koi"))
+		    latin1 = KOI8;
+		else if (streq(arg, "iso8859-7") || streq(arg, "el"))
+		    latin1 = GREEK;
 		else
-		    fatal("bad charset (not latin-1/2)");
+		    fatal("bad charset (not latin-1/2/koi8-r/iso8859-7)");
 		break;
 	    case 10:	// format
 		if (streq(arg, "help") || streq(arg, "?") || streq(arg, "list"))
@@ -264,6 +282,12 @@ main(int argc, char **argv)
 		if (timeout < 1 || timeout > 999999)
 		    fatal("bad timeout value", timeout);
 		break;
+  	    case 13:    // progname
+		progname = arg;
+		break;
+  	    case 14:    // pid
+		txtpid = strtoul(arg, NULL, 0);
+		break;
 	    case -1:	// non-option arg
 		if (not fmt)
 		    fmt = export_open(out_fmt);
@@ -283,7 +307,7 @@ main(int argc, char **argv)
 	fatal("no pages requested");
 
     // setup device
-    if (not(vbi = vbi_open(vbi_name, 0, fine_tune, newbttv)))
+    if (not(vbi = vbi_open(vbi_name, 0, fine_tune, newbttv, progname, txtpid)))
 	fatal("cannot open %s", vbi_name);
     vbi_add_handler(vbi, event, reqs); // register event handler
 
