@@ -136,6 +136,8 @@ option(int argc, char **argv, int *ind, char **arg)
 	{ "--help", "-h", 0 },
 	{ "-newbttv", "-new", 0 },
 	{ "-oldbttv", "-old", 0 },
+	{ "-progname", "-pn", 1 },
+	{ "-pid", "--pid", 1 },
     };
     int i;
 
@@ -166,12 +168,14 @@ option(int argc, char **argv, int *ind, char **arg)
 int
 main(int argc, char **argv)
 {
-    char *vbi_name = "/dev/vbi0";
+    char *vbi_name = NULL;
     int timeout = 0;
     int big_buf = -1;
     struct vbi *vbi;
     int opt, ind;
     char *arg;
+    char *progname = NULL;
+    int txtpid = -1;
 
     setprgname(argv[0]);
 
@@ -216,6 +220,12 @@ main(int argc, char **argv)
 	    case 9:	// oldbttv
 		big_buf = 0;
 		break;
+  	    case 10:    // progname
+		progname = arg;
+		break;
+  	    case 11:    // pid
+		txtpid = strtoul(arg, NULL, 0);
+		break;
 	    case -1:
 		usage(stderr, 1);
 		break;
@@ -229,7 +239,7 @@ main(int argc, char **argv)
 	alarm(timeout);
     }
 
-    vbi = vbi_open(vbi_name, 0, 1, big_buf);	// open device
+    vbi = vbi_open(vbi_name, 0, 1, big_buf, progname, txtpid);	// open device
     if (not vbi)
 	fatal_ioerror(vbi_name);
 
