@@ -40,7 +40,7 @@ event(int *quitflag, struct vt_event *ev)
 }
 
 
-void
+int
 main(int argc, char **argv)
 {
     int big_buf = -1;		// 0 for -oldbttv, 1 for -newbttv
