@@ -1,6 +1,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <locale.h>
 
 #include "vt.h"
 #include "misc.h"
@@ -16,13 +17,14 @@ int debug = 0;
 /* current args for next start() */
 static char *geometry;
 static char *dpy_name;
-static char *vbi_name = "/dev/vbi0";
+static char *vbi_name = NULL;
 static struct xio *xio;
 static struct vbi *vbi;
 static int fine_tune = 1; // auto = 999;
 static int erc = 1;
 static int newbttv = -1;
-
+static char *progname;
+static int txtpid = -1;
 
 static void
 usage(FILE *fp, int exitval)
@@ -33,16 +35,22 @@ usage(FILE *fp, int exitval)
 	    "  Valid options:\t\tDefault:\n"
 	    "    --help\n"
 	    "    --version\n"
-	    "    -vbi <vbidev>\t\t/dev/vbi0\n"
+	    "    -vbi <vbidev>\t\t/dev/vbi\n"
+		"                 \t\t/dev/vbi0\n"
+		"                 \t\t/dev/video0\n"
+		"                 \t\t/dev/dvb/adapter0/demux0\n"
 	    "    -display <dpy>\t\t$DISPLAY\n"
 	    "    -geometry <geo>\t\t41x25\n"
-	    "    -finetune <-4..4|auto>\t0\n"
-	    "    -child ppp[.ss]\n"
-	    "    [-parent] ppp[.ss]\t\t900\n"
+	    "    -finetune <-4..4|auto>\t1\n"
+	    "    -child <ppp[.ss]>\n"
+	    "    [-parent] <ppp[.ss]>\t900\n"
 	    //"    -oldbttv\t\t(for bttv <0.5.20)\n"
 	    "    -[no]erc\t\t\tenabled\n"
 	    "    -[no]bell\t\t\tenabled\n"
-	    "    -charset latin-1/2\t\tlatin-1\n"
+	    "    -charset <latin-1/2/koi8-r/\n"
+   	    "              iso8859-7>\tlatin-1\n"
+	    "    -progname <name>\n"
+	    "    -pid <pid>\n"
 	    "\n"
 	    "  Order is important!  Each page number\n"
 	    "  opens a new window with the previously\n"
@@ -54,8 +62,15 @@ usage(FILE *fp, int exitval)
 	    "  transmitted subpage is shown.\n"
 	    "\n"
 	    "  The -child option requires a parent\n"
-	    "  window.  So, it must be preceeded by\n"
+	    "  window.  So, it must be preceded by\n"
 	    "  a parent or another child window.\n"
+	    "\n"
+	    "  To use the DVB interface, use\n"
+	    "  -vbi /dev/dvb/adapter0/demux0\n"
+	    "\n"
+	    "  The -progname or -pid option specify\n"
+	    "  the program or teletext PID if using\n"
+	    "  the DVB interface.\n"
 	);
     exit(exitval);
 }
@@ -85,10 +100,20 @@ arg_pgno(char *p, int *subno)
 static struct vtwin *
 start(int argc, char **argv, struct vtwin *parent, int pgno, int subno)
 {
+    static int valid_vbi_name = 1;
+
+    if (!valid_vbi_name)
+	return parent;
+
     if (vbi == 0)
-	vbi = vbi_open(vbi_name, cache_open(), fine_tune, newbttv);
+	vbi = vbi_open(vbi_name, cache_open(), fine_tune, newbttv, progname, txtpid);
     if (vbi == 0)
-	fatal("cannot open %s", vbi_name);
+    {
+	if (vbi_name)
+	    error("cannot open device: %s", vbi_name);
+    	valid_vbi_name = 0;
+    	vbi = open_null_vbi(cache_open());
+    }
     if (vbi->cache)
 	vbi->cache->op->mode(vbi->cache, CACHE_MODE_ERC, erc);
 
@@ -100,6 +125,15 @@ start(int argc, char **argv, struct vtwin *parent, int pgno, int subno)
     parent = vtwin_new(xio, vbi, geometry, parent, pgno, subno);
     if (parent == 0)
 	fatal("cannot create window");
+
+    if (!valid_vbi_name)
+    {
+	if (vbi_name)
+	    send_errmsg(vbi, "cannot open device: %s", vbi_name);
+	else
+	    send_errmsg(vbi, "cannot open any device", vbi_name);
+    }
+
     return parent;
 }
 
@@ -126,6 +160,8 @@ option(int argc, char **argv, int *ind, char **arg)
 	{ "-bell", "-b", 0 },
 	{ "-nobell", "-nb", 0 },
 	{ "-charset", "-latin", 1 },
+	{ "-progname", "-pn", 1 },
+	{ "-pid", "--pid", 1 },
     };
     int i;
 
@@ -229,15 +265,25 @@ main(int argc, char **argv)
 		break;
 	    case 18:	// charset
 		if (streq(arg, "latin-1") || streq(arg, "1"))
-		    latin1 = 1;
+		    latin1 = LATIN1;
 		else if (streq(arg, "latin-2") || streq(arg, "2"))
-		    latin1 = 0;
+		    latin1 = LATIN2;
+		else if (streq(arg, "koi8-r") || streq(arg, "koi"))
+		    latin1 = KOI8;
+		else if (streq(arg, "iso8859-7") || streq(arg, "el"))
+		    latin1 = GREEK;
 		else
-		    fatal("bad charset (not latin-1/2)");
+		    fatal("bad charset (not latin-1/2/koi8-r/iso8859-7)");
 		break;
 	    case 12:	// debug
 		debug++;
 		break;
+  	    case 19:    // progname
+		progname = arg;
+		break;
+  	    case 20:    // pid
+		txtpid = strtoul(arg, NULL, 0);
+		break;
 	    case 6:	// parent
 	    case -1:	// non-option arg
 		pgno = arg_pgno(arg, &subno);
