@@ -36,6 +36,11 @@ struct vbi
     int bpb;			// bytes per bit * 2^16
     int bp8bl, bp8bh;		// bytes per 8-bit low/high
     int soc, eoc;		// start/end of clock run-in
+
+	// DVB stuff
+	unsigned int txtpid;
+	
+
 };
 
 struct vbi_client
@@ -46,7 +51,7 @@ struct vbi_client
 };
 
 struct vbi *vbi_open(char *vbi_dev_name, struct cache *ca, int fine_tune,
-								int big_buf);
+		     int big_buf, const char *progname, int txtpid);
 void vbi_close(struct vbi *vbi);
 void vbi_reset(struct vbi *vbi);
 int vbi_add_handler(struct vbi *vbi, void *handler, void *data);
@@ -54,4 +59,7 @@ void vbi_del_handler(struct vbi *vbi, void *handler, void *data);
 struct vt_page *vbi_query_page(struct vbi *vbi, int pgno, int subno);
 void vbi_pll_reset(struct vbi *vbi, int fine_tune);
 
+struct vbi *open_null_vbi(struct cache *ca);
+void send_errmsg(struct vbi *vbi, char *errmsg, ...);
+
 #endif
